@@ -81,7 +81,7 @@ class DictModel(models.Model, dict):
 
         :return: a dictionary which is json serializable
         """
-        return json_model_dict(self, use_float_seconds=use_float_seconds)
+        return json_model_dict(self.dict(), use_float_seconds=use_float_seconds)
 
     class Meta:
         abstract = True
