@@ -89,7 +89,7 @@ def required_keys(*keys, **kwargs):
     return wrapper
 
 
-def validate_keys(*key_validator_pairs, **kwargs):
+def validate_keys(*raw_key_validator_pairs, **kwargs):
     error_handler = kwargs.get('error_handler', None)
     if error_handler is None:
         error_handler = key_validation_failed_default_handler
@@ -104,22 +104,31 @@ def validate_keys(*key_validator_pairs, **kwargs):
             request_data = _get_request_data(request)
 
             # Check what's input
-            kv_pairs = key_validator_pairs
-            if len(key_validator_pairs)==2:
-                if isinstance(key_validator_pairs[0], (list, tuple, six.string_types)) and\
-                   (isinstance(key_validator_pairs[1], (list, tuple, types.FunctionType, staticmethod)) or
-                    hasattr(key_validator_pairs[1], '__call__')):
-                    kv_pairs = [(key_validator_pairs[0], key_validator_pairs[1])]
+            key_validator_pairs = raw_key_validator_pairs
+            if len(raw_key_validator_pairs)==2:
+                is_key_list = True
+                for item in raw_key_validator_pairs[0]:
+                    if not isinstance(item, six.string_types):
+                        is_key_list = False
+                        break
+                is_validator_list = True
+                for item in raw_key_validator_pairs[1]:
+                    if not isinstance(item, (types.FunctionType, staticmethod)):
+                        is_validator_list = False
+                        break
+                if is_key_list and is_validator_list:
+                    key_validator_pairs = (raw_key_validator_pairs,)
 
-            for request_key, validator_set in kv_pairs:
+            for request_key, validator in key_validator_pairs:
                 if not isinstance(request_key, (list, tuple)): keys = [request_key]
                 else: keys = request_key
 
-                if not isinstance(validator_set, (list, tuple)): validators = [validator_set]
-                else: validators = validator_set
+                if not isinstance(validator, (list, tuple)): validators = [validator]
+                else: validators = validator
 
                 for key in keys:
                     for validator in validators:
+                        print key, validator
                         if key in request_data:
                             try:
                                 if is_class_based:
